@@ -2,7 +2,7 @@ use warnings;
 use strict;
 
 package Net::Google::PicasaWeb;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 use Moose;
 
 use Carp;
@@ -22,7 +22,7 @@ Net::Google::PicasaWeb - use Google's Picasa Web API
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -203,7 +203,7 @@ This method also takes all the L</STANDARD LIST OPTIONS>.
 # This is a tiny cheat that allows us to reuse the list_entries method
 {
     package Net::Google::PicasaWeb::Tag;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
     sub from_feed {
         my ($class, $service, $entry) = @_;
@@ -319,7 +319,11 @@ It accepts the following parameters:
 
 =item user_id
 
-If given, the photos will be limited to those owned by this user. If it is set to "default", then the authenticated user will be used. If no C<user_id> is set, then the community feed will be used rather than a specific user.
+If given, the photos will be limited to those owned by this user. If it is set to "default", then the authenticated user will be used. If no C<user_id> is set, then the community feed will be used rather than a specific user. This option may not be combined with C<featured>.
+
+=item featured
+
+This can be set to a true value to fetch the current featured photos on PicasaWeb. This option is not compatible with C<user_id>.
 
 =back
 
@@ -333,9 +337,16 @@ sub list_media_entries {
     my ($self, %params) = @_;
     $params{kind} = 'photo';
 
-    my $user_id = delete $params{user_id};
-    my $path   = [ 'user', $user_id ] if $user_id;
-       $path ||= 'all';
+    my $user_id  = delete $params{user_id};
+    my $featured = delete $params{featured};
+    
+    croak "user_id may not be combined with featured"
+        if $user_id and $featured;
+
+    my $path;
+    $path   = [ 'user', $user_id ] if $user_id;
+    $path   = 'featured'           if $featured;
+    $path ||= 'all';
 
     return $self->list_entries(
         'Net::Google::PicasaWeb::MediaEntry',
